@@ -17,8 +17,8 @@
 // ========================================================================
 //
 // File          : $RCSfile: decoding.cc,v $
-// Revision      : $Revision: 1.28.2.4 $
-// Revision date : $Date: 2008/04/19 23:37:57 $
+// Revision      : $Revision: 1.28.2.7 $
+// Revision date : $Date: 2008/12/07 21:40:53 $
 // Author(s)     : Nicolas Rougier, Robert Sowada
 // Short         : Various functions for decoding, converting ...
 //
@@ -396,22 +396,24 @@ Decoding::decode_base64 (const std::string &todec)
 			|| (index_64[(int)todec[pos+1]]<0))
 			return std::string("");
 		result += (gchar)((BASE64(pos) << 2) | (BASE64(pos+1) >> 4));
-		if (todec[pos+2] == '=')
+		if (todec[pos+2] == '=') {
 			if ((todec[pos+3]=='=') && (pos+4==len) && (!(BASE64(pos+1)&15)))
 				return result;
 			else
 				return std::string("");
+		}
 		if (index_64[(int)todec[pos+2]]<0)
 			return std::string("");
 		result += (gchar)(((BASE64(pos+1) & 0xf) << 4) | (BASE64(pos+2) >> 2));
-		if (todec[pos+3] == '=')
+		if (todec[pos+3] == '=') {
 			if ((pos+4 == len) && (!(BASE64(pos+2)&3)))
 				return result;
 			else
 				return std::string("");
+		}
 		if (index_64[(int)todec[pos+3]]<0)
 			return std::string("");
-		result += (gchar)(((BASE64(pos+2) & 0x3) << 6) | BASE64(pos+3));
+		result += static_cast<gchar>((((BASE64(pos+2) & 0x3) << 6) | BASE64(pos+3)));
 		pos += 4;
 	}
 	return result;
@@ -506,7 +508,7 @@ Decoding::decode_quotedprintable (const std::string &todec)
 
 	while (pos < len)
 	{
-		switch (gchar c=todec.at(pos++))
+		switch (gchar c = todec.at(pos++))
 		{
 			case '=':
 				pos += 2;
@@ -822,7 +824,7 @@ std::string
 Decoding::decrypt_aes (const std::string &passphrase, const std::string &data)
 {
 #ifdef HAVE_AES
-	unsigned char *phraseptr = (unsigned char *)passphrase.c_str ();
+	const unsigned char *phraseptr = reinterpret_cast<const unsigned char *>(passphrase.c_str ());
 	guint phraselen = passphrase.size();
 
 	// Check Passphrase
@@ -856,7 +858,7 @@ Decoding::decrypt_aes (const std::string &passphrase, const std::string &data)
 	}
 
 	// Free memory
-	std::string result_str = std::string ((char *)result);
+	std::string result_str = std::string (reinterpret_cast<char *>(result));
 	delete (bin);
 	delete (result);
 
@@ -883,8 +885,8 @@ Decoding::encrypt_aes (const std::string &passphrase, const std::string &data)
 {
 #ifdef HAVE_AES
 	const char hex[] = "0123456789ABCDEF";
-	unsigned char *dataptr = (unsigned char *)data.c_str ();
-	unsigned char *phraseptr = (unsigned char *)passphrase.c_str ();
+	const unsigned char *dataptr = reinterpret_cast<const unsigned char *>(data.c_str ());
+	const unsigned char *phraseptr = reinterpret_cast<const unsigned char *>(passphrase.c_str ());
 	guint phraselen = passphrase.size();
 
 	// Check Passphrase
@@ -915,7 +917,7 @@ Decoding::encrypt_aes (const std::string &passphrase, const std::string &data)
 	}
 
 	// Free memory
-	std::string result_str = std::string ((char *)result, 2*size);
+	std::string result_str = std::string (reinterpret_cast<char *>(result), 2*size);
 	delete (result);
 
 	return result_str;
