@@ -17,8 +17,8 @@
 // ========================================================================
 //
 // File          : $RCSfile: socket.cc,v $
-// Revision      : $Revision: 1.32.2.3 $
-// Revision date : $Date: 2010/02/06 14:39:37 $
+// Revision      : $Revision: 1.32.2.4 $
+// Revision date : $Date: 2012/02/26 09:21:47 $
 // Author(s)     : Nicolas Rougier, Robert Sowada
 // Short         : 
 //
@@ -401,15 +401,25 @@ Socket::read (std::string &line, gboolean print, gboolean check)
 					   line.c_str());
 			break;
 		default:
-			g_message ("[%d] RECV ERROR(%s:%d): %s", uin_, hostname_.c_str(),
-					   port_, strerror(status));
+			if (cnt <= 0)
+				g_message ("[%d] RECV ERROR(%s:%d): line too long, "
+				           "security/prevdos_line_length should be increased",
+						   uin_, hostname_.c_str(), port_);
+			else
+				g_message ("[%d] RECV ERROR(%s:%d): %s", uin_,
+						   hostname_.c_str(), port_,
+						   strerror(status));
 			break;
 		}
 	}
 #endif
 	if (status_ == SOCKET_STATUS_ERROR) {
-		g_warning (_("[%d] Unable to read from %s on port %d"), uin_,
-				   hostname_.c_str(), port_);
+		if (cnt <= 0)
+			g_warning (_("[%d] line too long, security/prevdos_line_length "
+				     "should be increased"), uin_);
+		else
+			g_warning (_("[%d] Unable to read from %s on port %d"),
+					   uin_, hostname_.c_str(), port_);
 		close();
 	}
 
