@@ -1,6 +1,6 @@
 // ========================================================================
 // gnubiff -- a mail notification program
-// Copyright (c) 2000-2007 Nicolas Rougier, 2004-2007 Robert Sowada
+// Copyright (c) 2000-2011 Nicolas Rougier, 2004-2011 Robert Sowada
 //
 // This program is free software: you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -17,8 +17,8 @@
 // ========================================================================
 //
 // File          : $RCSfile: ui-applet-gui.cc,v $
-// Revision      : $Revision: 1.10.2.7 $
-// Revision date : $Date: 2008/04/25 22:53:07 $
+// Revision      : $Revision: 1.10.2.10 $
+// Revision date : $Date: 2012/01/08 21:00:23 $
 // Author(s)     : Nicolas Rougier, Robert Sowada
 // Short         : 
 //
@@ -399,7 +399,7 @@ AppletGUI::hide_dialog_preferences (void)
 gboolean 
 AppletGUI::visible_dialog_preferences (void)
 {
-	return (preferences_ && GTK_WIDGET_VISIBLE (preferences_->get ()));
+	return (preferences_ && gtk_widget_get_visible (preferences_->get ()));
 }
 
 /**
@@ -462,7 +462,7 @@ AppletGUI::hide_dialog_popup (void)
 gboolean 
 AppletGUI::visible_dialog_popup (void)
 {
-	return (popup_ && GTK_WIDGET_VISIBLE (popup_->get ("dialog")));
+	return (popup_ && gtk_widget_get_visible (popup_->get ("dialog")));
 }
 
 /**
@@ -523,8 +523,7 @@ AppletGUI::tooltip_update (void)
 	std::string text = get_mailbox_status_text ();
 
 	// Put text in tooltip
-	GtkTooltipsData *data = gtk_tooltips_data_get (tooltip_widget_);
-	gtk_tooltips_set_tip (data->tooltips, tooltip_widget_, text.c_str(), "");
+    gtk_widget_set_tooltip_text (tooltip_widget_, text.c_str());
 }
 
 
