@@ -17,8 +17,8 @@
 // ========================================================================
 //
 // File          : $RCSfile: ui-popup.cc,v $
-// Revision      : $Revision: 1.39.2.5 $
-// Revision date : $Date: 2008/04/25 22:53:14 $
+// Revision      : $Revision: 1.39.2.7 $
+// Revision date : $Date: 2012/01/08 21:00:23 $
 // Author(s)     : Nicolas Rougier, Robert Sowada
 // Short         : 
 //
@@ -107,7 +107,7 @@ extern "C" {
 	}
 }
 
-Popup::Popup (Biff *biff) : GUI (GNUBIFF_DATADIR"/popup.glade")
+Popup::Popup (Biff *biff) : GUI (GNUBIFF_DATADIR"/popup.ui")
 {
 	biff_ = biff;
 	poptag_ = 0;
